@@ -10,13 +10,12 @@
 
 #include "weaverimplstate.h"
 
-
 namespace ThreadWeaver
 {
-
 WeaverImplState::WeaverImplState(QueueSignals *weaver)
     : State(weaver)
-{}
+{
+}
 
 const State *WeaverImplState::state() const
 {
@@ -55,7 +54,7 @@ int WeaverImplState::currentNumberOfThreads() const
     return weaver()->currentNumberOfThreads_p();
 }
 
-void WeaverImplState::enqueue(const QVector<JobPointer> &jobs)
+void WeaverImplState::enqueue(const QList<JobPointer> &jobs)
 {
     weaver()->enqueue_p(jobs);
 }
